import axios from 'axios'
import Router from '../router/index'
import { Message, MessageBox } from 'element-ui';
const service = axios.create({
  timeout: 10000
});

/**
 * 请求拦截
 */
 service.interceptors.request.use(config => {
  config.headers['AccessToken'] = sessionStorage.getItem('AccessToken') || ''
  return config
}, error => {
  return Promise.reject(error)
})

/**
 * 响应拦截
 */
 service.interceptors.response.use(response => {
  if (response.status !== 200) {
    Message.error('请求失败')
    return Promise.reject('请求失败: status code !== 200')
  } else {
    if (response.data.code !== '200') {
      if (response.data.subCode == '101') {
        MessageBox.alert(response.data.subMsg || '请求失败', '提示',{
          type: 'error',
          confirmButtonText: '重新登录',
          closeOnClickModal: false,
          closeOnPressEscape: false,
          callback: function (action) {
            if (action == 'confirm') {
              sessionStorage.clear()
              Router.replace({
                path: '/login'
              })
            }
          }
        })
        return Promise.reject(response.data.subMsg || '登录失效')
      } else {
        Message.error(response.data.msg || '请求失败')
        return Promise.reject(response.data.msg || '请求失败')
      }
    } else {
      return  Promise.resolve(response.data)
    }
  }
}, error => {
  Message.error(error.message)
  return Promise.reject(error)
})

export default service